"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const env_1 = require("../env");
const loaders_1 = require("../webpack/loaders");
const plugins_1 = require("../webpack/plugins");
const cssExtractor = plugins_1.createCssExtractTextPlugin();
const ENV = tslib_1.__importStar(require("../env"));
const prodConfig = {
    resolve: {
        symlinks: true,
        extensions: ['.ts', '.tsx', '.js', '.jsx', '.styl'],
    },
    resolveLoader: {
        modules: [ENV.TOOLS_NODE_MODULES_PATH],
    },
    entry: {
        index: [require.resolve(`${env_1.SRC_PATH}/index.tsx`)],
    },
    output: {
        path: `${env_1.ROOT}/build`,
        filename: '[name].[chunkhash:8].js',
    },
    module: {
        rules: [
            {
                oneOf: [
                    {
                        test: loaders_1.TS_PATTERN,
                        use: [loaders_1.babelLoader, loaders_1.tsLoader],
                    },
                    {
                        test: loaders_1.STYLUS_PATTERN,
                        use: cssExtractor.extract({
                            fallback: loaders_1.styleLoader,
                            use: [loaders_1.cssLoader, loaders_1.postcssLoader, loaders_1.stylusLoader],
                        }),
                    },
                    {
                        test: loaders_1.CSS_PATTERN,
                        use: cssExtractor.extract({
                            fallback: loaders_1.styleLoader,
                            use: [loaders_1.cssLoader, loaders_1.postcssLoader],
                        }),
                    },
                    {
                        exclude: loaders_1.FILE_LOADER_EXCLUDES,
                        use: [loaders_1.fileLoader],
                    },
                ],
            },
        ],
    },
    plugins: [cssExtractor, plugins_1.createHtmlPlugin(), plugins_1.createForkTSCheckerPlugin()],
};
exports.default = prodConfig;
