"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const webpack_1 = tslib_1.__importDefault(require("webpack"));
const ENV = tslib_1.__importStar(require("../env"));
const loaders_1 = require("../webpack/loaders");
const plugins_1 = require("../webpack/plugins");
module.exports = async ({ config }) => {
    config.plugins = config.plugins || [];
    return {
        entry: config.entry,
        output: config.output,
        module: {
            rules: [
                {
                    oneOf: [
                        {
                            test: loaders_1.TS_PATTERN,
                            use: [loaders_1.babelLoader, loaders_1.tsLoader],
                        },
                        {
                            test: loaders_1.STYLUS_PATTERN,
                            use: [loaders_1.styleLoader, loaders_1.cssLoader, loaders_1.postcssLoader, loaders_1.stylusLoader],
                        },
                        {
                            test: loaders_1.CSS_PATTERN,
                            use: [loaders_1.styleLoader, loaders_1.cssLoader, loaders_1.postcssLoader],
                        },
                        {
                            exclude: loaders_1.FILE_LOADER_EXCLUDES,
                            use: [loaders_1.fileLoader],
                        },
                    ],
                },
            ],
        },
        plugins: [
            ...config.plugins,
            plugins_1.createForkTSCheckerPlugin(),
            new webpack_1.default.DefinePlugin({
                SRC_PATH: JSON.stringify(ENV.SRC_PATH),
            }),
        ],
        resolve: {
            symlinks: true,
            extensions: ['.ts', '.tsx', '.js', '.jsx', '.styl'],
        },
        resolveLoader: {
            modules: [ENV.TOOLS_NODE_MODULES_PATH],
        },
        mode: 'development',
    };
};
