"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const path_1 = tslib_1.__importDefault(require("path"));
const webpack_dev_server_1 = tslib_1.__importDefault(require("webpack-dev-server"));
const env_1 = require("../config/env");
const webpack_1 = tslib_1.__importDefault(require("webpack"));
const dev_1 = tslib_1.__importDefault(require("../config/build/dev"));
const program_1 = require("../utils/program");
const constants_1 = require("./constants");
const WebpackDevServerUtils_1 = require("react-dev-utils/WebpackDevServerUtils");
const program = program_1.getProgramForScript(constants_1.Scripts.DEV_SERVER);
process.env.PUBLIC_URL = path_1.default.join(env_1.ROOT, 'public');
console.log('starting...');
const serverConfig = {
    compress: true,
    clientLogLevel: 'none',
    hot: true,
    quiet: true,
    overlay: false,
    historyApiFallback: {
        // Paths with dots should still use the history fallback.
        // See https://github.com/facebookincubator/create-react-app/issues/387.
        disableDotRule: true,
    },
};
program
    .command('dev-server')
    .option('-p --port [portnumber]', 'dev-server port', value => parseInt(value, 10), 8080)
    .option('-h --host [hostname]', 'dev-server host', 'localhost')
    .action(function (options) {
    return WebpackDevServerUtils_1.choosePort(options.host, options.port).then(port => {
        if (!port) {
            throw new Error(`Port ${options.port} already in use`);
        }
        const protocol = process.env.HTTPS === 'true' ? 'https' : 'http';
        const appName = env_1.PKG.name;
        const urls = WebpackDevServerUtils_1.prepareUrls(protocol, options.host, port);
        // Create a webpack compiler that is configured with custom messages.
        const compiler = WebpackDevServerUtils_1.createCompiler(webpack_1.default, dev_1.default, appName, urls, false);
        const devServer = new webpack_dev_server_1.default(compiler, serverConfig);
        devServer.listen(port, options.host, err => {
            if (err) {
                return console.log(err);
            }
            console.log('Starting the devlopment server...\n');
        });
        ['SIGINT', 'SIGTERM'].forEach(function (sig) {
            process.on(sig, function () {
                devServer.close();
                process.exit();
            });
        });
    });
});
program.parse(process.argv);
