"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const webpack_1 = tslib_1.__importDefault(require("webpack"));
const ENV = tslib_1.__importStar(require("../config/env"));
/**
 * Runs webpack compiler as a promise
 * @param {Object} config
 * @returns {Promise}
 */
function build(config) {
    return new Promise((resolve, reject) => {
        webpack_1.default(config, (error, stats) => {
            if (error) {
                return reject(error);
            }
            else {
                const jsonStats = stats.toJson();
                if (jsonStats.errors.length > 0) {
                    return reject(jsonStats.errors);
                }
                else {
                    resolve(stats);
                }
            }
        });
    })
        .then((stats) => {
        console.log('Done');
        console.log(stats.toString(ENV.STATS));
    })
        .catch(e => {
        const errors = Array.isArray(e) ? e : [e];
        errors.forEach(error => {
            console.error();
            console.error(error.stack || error);
            console.error();
        });
        process.exit(1);
    });
}
exports.build = build;
