"use strict";
// copy-paste from "lerna"
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const chalk_1 = tslib_1.__importDefault(require("chalk"));
const execa_1 = tslib_1.__importDefault(require("execa"));
const strong_log_transformer_1 = tslib_1.__importDefault(require("strong-log-transformer"));
// bookkeeping for spawned processes
let children = 0;
// when streaming children are spawned, use this color for prefix
const colorWheel = ['cyan', 'magenta', 'blue', 'yellow', 'green', 'red'];
const NUM_COLORS = colorWheel.length;
function exec(command, args, opts) {
    const options = Object.assign({}, opts);
    options.stdio = 'pipe'; // node default
    return _spawn(command, args, options);
}
exports.exec = exec;
function execSync(command, args, opts) {
    return execa_1.default.sync(command, args, opts).stdout;
}
exports.execSync = execSync;
function spawn(command, args, opts) {
    const options = Object.assign({}, opts);
    options.stdio = 'inherit';
    return _spawn(command, args, options);
}
exports.spawn = spawn;
// istanbul ignore next
function spawnStreaming(command, prefix, args, opts) {
    const options = Object.assign({}, opts);
    options.stdio = ['ignore', 'pipe', 'pipe'];
    const colorName = colorWheel[children % NUM_COLORS];
    const color = chalk_1.default[colorName];
    const spawned = _spawn(command, args, options);
    const prefixedStdout = strong_log_transformer_1.default({ tag: `${color.bold(prefix)}:` });
    const prefixedStderr = strong_log_transformer_1.default({ tag: `${color(prefix)}:`, mergeMultiline: true });
    // Avoid "Possible EventEmitter memory leak detected" warning due to piped stdio
    if (children > process.stdout.listenerCount('close')) {
        process.stdout.setMaxListeners(children);
        process.stderr.setMaxListeners(children);
    }
    spawned.stdout && spawned.stdout.pipe(prefixedStdout).pipe(process.stdout);
    spawned.stderr && spawned.stderr.pipe(prefixedStderr).pipe(process.stderr);
    return spawned;
}
exports.spawnStreaming = spawnStreaming;
function getChildProcessCount() {
    return children;
}
exports.getChildProcessCount = getChildProcessCount;
// eslint-disable-next-line no-underscore-dangle
function _spawn(command, args, opts) {
    children += 1;
    const child = execa_1.default(command, args, opts);
    const drain = (code, signal) => {
        children -= 1;
        // don't run repeatedly if this is the error event
        if (signal === undefined) {
            child.removeListener('exit', drain);
        }
    };
    child.once('exit', drain);
    child.once('error', drain);
    return child;
}
